﻿local LibStub = LibStub
local tinsert = tinsert
local tremove = tremove
local type = type

local addon = LibStub("AceAddon-3.0"):GetAddon("AverageCombatMana")
local L = addon.L

function addon:OptionsTable()
	local options = {
		name = "Average Combat Mana",
		handler = addon,
		type = "group",
		childGroups = "tab",
		args = {
			general = {
				name = GENERAL_LABEL,
				type = "group",
				order = 1,
				args = {
					addonEnabled = {
						order = 10,
						type = "toggle",
						name = L["Enable Average Combat Mana"],
						get = function() return self.db.profile.addonEnabled end,
						set = function(info, value)
							self.db.profile.addonEnabled = value
							if value then
								self:Enable()
							else
								self:Disable()
							end
						end
					},
					showBar = {
						order = 20,
						type = "toggle",
						name = L["Show Bar"],
						get = function() return self.db.profile.showBar end,
						set = function(info, value)
							if value then
								if not ACM.ManaDisplay:IsShown() then
									ACM.ManaDisplay:Show()
								end
							else
								if ACM.ManaDisplay:IsShown then
									ACM.ManaDisplay:Hide()
								end
							end
						end
					},
					spacer1 = {
						order = 40,
						type = "description",
						name = ""
					},
					chatOutput = {
						order = 50,
						type = "select",
						name = CHAT_OPTIONS_LABEL,
						desc = L["Chat channel you want your overall Mana regen to print. Smart Group will select Party or Raid depending on group type"],
						values = {
							["0-smartGroup"] = L["Smart Group"],
							["1-self"] = YOU,
							["2-none"] = NONE,
							guild = CHAT_MSG_GUILD,
							party = CHAT_MSG_PARTY,
							raid = CHAT_MSG_RAID,
							say = CHAT_MSG_SAY,
							yell = CHAT_MSG_YELL
						},
						get = function() return self.db.profile.chatOutput end,
						set = function(info, value)	self.db.profile.chatOutput = value end
					}
				}
			},
			barOptions = {
				name = L["Bar Options"],
				type = "group",
				order = 10,
				args = {
					barBorderColor = {
						order = 10,						
						type = "color",
						name = L["Bar Border Colour"],
						hasAlpha = true,
						get = function()
							local t = self.db.profile.barBorderColor
							return t.r, t.g, t.b, t.a
						end,
						set = function(info, r, g, b, a)
							local t = self.db.profile.barBorderColour
							t.r, t.g, t.b, t.a = r, g, b, a
						end
					},
					negTextColor = {
						order = 20,
						type = "color",
						name = L["Negative Value Text Colour"],
						hasAlpha = false,
						get = function()
							local t = self.db.profile.negTextColor
							return t.r, t.g, t.b
						end,
						set = function(info, r, g, b)
							local t = self.db.profile.negTextColor
							t.r, t.g, t.b = r, g, b
						end
					},
					posTextColor = {
						order = 30,
						type = "color",
						name = L["Positive Value Text Colour"],
						hasAlpha = false,
						get = function()
							local t = self.db.profile.posTextColor
							return t.r, t.g, t.b
						end,
						set = function(info, r, g, b)
							local t = self.db.profile.posTextColor
							t.r, t.g, t.b = r, g, b
						end
					},
					spacer2 = {
						order = 40,
						type = "description",
						name = ""
					},
					barHeight = {
						order = 50,
						type = "range",
						name = L["Bar Height"],
						get = function() return self.db.profile.barHeight end,
						set = function(info, value) self.db.profile.barHeight = value end,
						min = 10,
						max = 50,
						step = 1
					},
					barWidth = {
						order = 60,
						type = "range",
						name = L["Bar Width"],
						get = function() return self.db.profile.barWidth end,
						set = function(info, value) self.db.profile.barWidth = value end,
						min = 150,
						max = 400,
						step = 1
					},
					spacer3 = {
						order = 70,
						type = "description",
						name = ""
					},
					barBorder = {
						order = 80,
						type = "select",
						dialogControl = "LSM30_Border",						
						name = L["Bar Border"],
						values = AceGUIWidgetLSMlists.border,
						get = function() return self.db.profile.barBorder end,
						set = function(info, value) self.db.profile.barBorder = value end
					},
					spacer4 = {
						order = 90,
						type = "description",
						name = ""
					},
					messageFont = {
						order = 100,
						type = "select",
						dialogControl = "LSM30_Font",
						name = L["Message Font"],
						values = AceGUIWidgetLSMlists.font,
						get = function() return self.db.profile.messageFont end,
						set = function(info, value) self.db.profile.messageFont = value end
					},
					messageFontSize = {
						order = 110,
						type = "select",
						name = FONT_SIZE,
						desc = L["Message Font Size"],
						values = {
							8 = 8,
							9 = 9,
							10 = 10,
							12 = 12,
							14 = 14,
							16 = 16,
							18 = 18,
							20 = 20,
							24 = 24
						},
						get = function() return self.db.profile.messageFontSize end,
						set = function(info, value) self.db.profile.messageFontSize = value end
					},
					messageFontEffects = {
						order = 120,
						type = "select",
						name = L["Message Font Effects"],
						values = {
							monochrome = L["Monochrome"],
							outline = L["Outline"],
							thickOut = L["Thick Outline"]
						},
						get = function() return self.db.profile.messageFontEffects end,
						set = function(info, value) self.db.profile.messageFontEffects = value end
					},
					spacer5 = {
						order = 130,
						type = "description",
						name = ""
					},
					ManaFont = {
						order = 140,
						type = "select",
						dialogControl = "LSM30_Font",
						name = L["Mana Font"],
						values = AceGUIWidgetLSMlists.font,
						get = function() return self.db.profile.manaFont end,
						set = function(info, value) self.db.profile.manaFont = value end
					},
					manaFontSize = {
						order = 150,
						type = "select",
						name = FONT_SIZE,
						desc = L["Mana Font Size"],
						values = {
							8 = 8,
							9 = 9,
							10 = 10,
							12 = 12,
							14 = 14,
							16 = 16,
							18 = 18,
							20 = 20,
							24 = 24
						},
						get = function() return self.db.profile.manaFontSize end,
						set = function(info, value) self.db.profile.manaFontSize = value end
					},
					manaFontEffects = {
						order = 160,
						type = "select",
						name = L["Mana Font Effects"],
						values = {
							monochrome = L["Monochrome"],
							outline = L["Outline"],
							thickOut = L["Thick Outline"]
						},
						get = function() return self.db.profile.manaFontEffects end,
						set = function(info, value) self.db.profile.manaFontEffects = value end
					}
				},
			helpTab = {
					order = 20,
					type = "group",
					name = HELP_LABEL,
					args = {
						helpHeader1 = {
							order = 10,
							type = "header",
							name = L["Bar Help"],							
						},
						helpDesc1 = {
							order = 20,
							type = "description",
							name = "* "..L["To move the bar, hold down the ALT key and drag with the left mouse button"]
						},
						helpDesc2 = {
							order = 30,
							type = "description",
							name = "* "..L["The bar must be shown in combat or nothing will work."]
						},
						helpDesc3 = {
							order = 40,
							type = "description",
							name = L["Therefore the bar is automatically turned on during combat."]
						},
						spacer6 = {
							order = 100,
							type = "description",
							name = ""
						},
						helpHeader4 = {
							order = 110,
							type = "header",
							name = L["What Does this Addon Do?"]
						},
						helpDesc5 = {
							order = 120,
							type = "description",
							name = "* "..L["Every two seconds, your current Mana is grabbed, then compared to the previous value."]
						},
						helpDesc6 = {
							order = 130,
							type = "description",
							name = L["The five most recent values are averaged, and that number moves the indicator."]
						},
						helpDesc7 = {
							order = 140,
							type = "description",
							name = L["There is an initial warm up of ten seconds, then the indicator moves every two seconds thereafter."]
						}
					}
				}
			},
			creditsTab = {
				order = 30,
				type = "group",
				name = L["Credits"],
				args = {
					credits1 = {
						order = 10,
						type = "description",
						name = "* "..L["The idea for this addon came from Repose AKA Odobenus from Knights of the Storm, Alliance US Llane"]
					}
				}
			}
		}
	}
	return options
end